Command Line Interface — Numina 0.20.dev0 documentation

# Command Line Interface

The numina script is the interface with the pipelines It is called like this:

    $ numina [global-options] comands [comand-options]

The numina script has several options:

`-d````,` `--debug```

  Debug enabled, increases verbosity.

`-l` `filename`

  A file con configuration options for logging.

## Options for run

The run subcommand processes the observing result with the appropriated reduction recipe.

It is called like this:

    $ numina [global-options] run [comand-options] observation-result.yaml

`--instrument``'name'`

  Name of one of the predefined instrument configurations.

`--pipeline``'name'`

  Name of one of the predefined pipelines.

`--requirements` `filename`

  File with the description of the parameters of the recipe.

`--basedir` `path`

  File path used to resolve relative paths in the following options.

`--datadir` `path`

  File path to the folder containing the pristine data to be processed.

`--resultsdir` `path`

  File path to the directory where results are stored.

`--workdir` `path`

  File path to the a directory where the recipe can write. Files in datadir are copied here.

`--cleanup```

  Remove intermediate and temporal files created by the recipe.

`observing_result` `filename`

  Filename contaning the description of the observation result.

## Options for show-instruments

The show-instruments subcommand outputs information about the instruments with available pipelines.

It is called like this:

    $ numina [global-options] show-instruments [options]

`-o````,` `--observing-modes```

  Show names and keys of Observing Modes in addition of instrument information.

`name```

  Name of the instruments to show. If empty show all instruments.

## Options for show-modes

The show-modes subcommand outputs information about the observing modes of the available instruments.

It is called like this:

    $ numina [global-options] show-modes [options]

`-i````,` `--instrument` `name`

  Filter modes by instrument name.

`name```

  Name of the observing mode to show. If empty show all observing modes.

## Options for show-recipes

The show-recipes subcommand outputs information about the recipes of the available instruments.

It is called like this:

    $ numina [global-options] show-recipes [options]

`-i````,` `--instrument` `name`

  Filter recipes by instrument name.

`-m````,` `--mode```

  Filter recipes by observing mode.

`name```

  Name of the recipe to show. If empty show all recipes.